Examples of schema definitions and usage with Kafka Metamorphosis
Examples of schema definitions and usage with Kafka Metamorphosis
(advanced-composition-examples)Advanced schema composition patterns
Advanced schema composition patterns
(basic-schemas-example)Examples of basic schema definitions
Examples of basic schema definitions
(collections-example)Examples with collections and arrays
Examples with collections and arrays
(custom-predicates-example)Examples using custom predicates
Examples using custom predicates
(ecommerce-example)Complex e-commerce schema example
Complex e-commerce schema example
(events-example)Examples for event and logging schemas
Examples for event and logging schemas
(nested-structures-example)Examples with nested map structures
Examples with nested map structures
(run-all-examples)Run all schema examples
Run all schema examples
(run-composition-examples)Run all composition examples
Run all composition examples
(schema-composition-examples)Examples demonstrating schema composition features
Examples demonstrating schema composition features
(validation-examples)Examples of validation and error explanation
Examples of validation and error explanation
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |