kafka-metamorphosis.streams

Kafka Streams wrapper for Kafka Metamorphosis.

Kafka Streams wrapper for Kafka Metamorphosis.
raw docstring

branchclj

(branch stream predicates)

Split a KStream into multiple streams using a sequence of predicate functions. Returns a vector of KStreams in the same order as predicates.

Split a KStream into multiple streams using a sequence of predicate functions.
Returns a vector of KStreams in the same order as predicates.
sourceraw docstring

build-topologyclj

(build-topology builder)

Build a Topology from a StreamsBuilder.

Build a Topology from a StreamsBuilder.
sourceraw docstring

clean-up!clj

(clean-up! streams)

Clean up local state for the Kafka Streams instance.

Clean up local state for the Kafka Streams instance.
sourceraw docstring

close!clj

(close! streams)
(close! streams timeout-ms)

Close the Kafka Streams instance. Optionally provide a timeout in milliseconds.

Close the Kafka Streams instance.
Optionally provide a timeout in milliseconds.
sourceraw docstring

createclj

(create topology config)

Create a KafkaStreams instance from an existing Topology and config map.

Create a KafkaStreams instance from an existing Topology and config map.
sourceraw docstring

create-builderclj

(create-builder)

Create a new Kafka Streams builder.

Create a new Kafka Streams builder.
sourceraw docstring

create-from-builderclj

(create-from-builder builder config)

Create a KafkaStreams instance from a StreamsBuilder and config map.

Create a KafkaStreams instance from a StreamsBuilder and config map.
sourceraw docstring

default-application-idclj

Default Kafka Streams application id.

Default Kafka Streams application id.
sourceraw docstring

filter-streamclj

(filter-stream stream pred)

Filter records from a KStream using a predicate function of [key value].

Filter records from a KStream using a predicate function of [key value].
sourceraw docstring

map-valuesclj

(map-values stream f)

Transform the values of a KStream using f.

f receives the current value and should return the transformed value.

Transform the values of a KStream using f.

f receives the current value and should return the transformed value.
sourceraw docstring

start!clj

(start! streams)

Start the Kafka Streams instance.

Start the Kafka Streams instance.
sourceraw docstring

stateclj

(state streams)

Return the current Kafka Streams state.

Return the current Kafka Streams state.
sourceraw docstring

streamclj

(stream builder topics)

Create a KStream from a builder and a topic or list of topics.

Create a KStream from a builder and a topic or list of topics.
sourceraw docstring

streams-configclj

(streams-config)
(streams-config application-id)
(streams-config application-id overrides)

Create a Kafka Streams configuration map with sensible defaults.

Usage: (streams-config) ; local brokers and default application id (streams-config "my-app") ; custom application id (streams-config "my-app" {:bootstrap-servers "kafka:9092"})

Create a Kafka Streams configuration map with sensible defaults.

Usage:
(streams-config)                             ; local brokers and default application id
(streams-config "my-app")                  ; custom application id
(streams-config "my-app" {:bootstrap-servers "kafka:9092"})
sourceraw docstring

toclj

(to stream topic)

Send a KStream to the given topic and return the same stream.

Send a KStream to the given topic and return the same stream.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries