Kafka Streams wrapper for Kafka Metamorphosis.
Kafka Streams wrapper for Kafka Metamorphosis.
(branch stream predicates)Split a KStream into multiple streams using a sequence of predicate functions. Returns a vector of KStreams in the same order as predicates.
Split a KStream into multiple streams using a sequence of predicate functions. Returns a vector of KStreams in the same order as predicates.
(build-topology builder)Build a Topology from a StreamsBuilder.
Build a Topology from a StreamsBuilder.
(clean-up! streams)Clean up local state for the Kafka Streams instance.
Clean up local state for the Kafka Streams instance.
(close! streams)(close! streams timeout-ms)Close the Kafka Streams instance. Optionally provide a timeout in milliseconds.
Close the Kafka Streams instance. Optionally provide a timeout in milliseconds.
(create topology config)Create a KafkaStreams instance from an existing Topology and config map.
Create a KafkaStreams instance from an existing Topology and config map.
(create-builder)Create a new Kafka Streams builder.
Create a new Kafka Streams builder.
(create-from-builder builder config)Create a KafkaStreams instance from a StreamsBuilder and config map.
Create a KafkaStreams instance from a StreamsBuilder and config map.
Default Kafka Streams application id.
Default Kafka Streams application id.
(filter-stream stream pred)Filter records from a KStream using a predicate function of [key value].
Filter records from a KStream using a predicate function of [key value].
(map-values stream f)Transform the values of a KStream using f.
f receives the current value and should return the transformed value.
Transform the values of a KStream using f. f receives the current value and should return the transformed value.
(start! streams)Start the Kafka Streams instance.
Start the Kafka Streams instance.
(state streams)Return the current Kafka Streams state.
Return the current Kafka Streams state.
(stream builder topics)Create a KStream from a builder and a topic or list of topics.
Create a KStream from a builder and a topic or list of topics.
(streams-config)(streams-config application-id)(streams-config application-id overrides)Create a Kafka Streams configuration map with sensible defaults.
Usage: (streams-config) ; local brokers and default application id (streams-config "my-app") ; custom application id (streams-config "my-app" {:bootstrap-servers "kafka:9092"})
Create a Kafka Streams configuration map with sensible defaults.
Usage:
(streams-config) ; local brokers and default application id
(streams-config "my-app") ; custom application id
(streams-config "my-app" {:bootstrap-servers "kafka:9092"})(to stream topic)Send a KStream to the given topic and return the same stream.
Send a KStream to the given topic and return the same stream.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |